@@ -1,7 +1,7 @@
 package Complete;
 
-our $DATE = '2015-11-29'; # DATE
-our $VERSION = '0.18'; # VERSION
+our $DATE = '2015-12-17'; # DATE
+our $VERSION = '0.19'; # VERSION
 
 1;
 # ABSTRACT: Convention for Complete::* modules family
@@ -18,7 +18,7 @@ Complete - Convention for Complete::* modules family
 
 =head1 VERSION
 
-This document describes version 0.18 of Complete (from Perl distribution Complete), released on 2015-11-29.
+This document describes version 0.19 of Complete (from Perl distribution Complete), released on 2015-12-17.
 
 =head1 DESCRIPTION
 
@@ -43,8 +43,8 @@ Modules usually are named after the type of completion answer they provide. For
 example: L<Complete::Unix> completes username/group name,
 L<Complete::Getopt::Long> completes from L<Getopt::Long> specification,
 L<Complete::Module> completes Perl module names, and so on. A current exception
-is L<Complete::Util> which contains several routines to complete from
-common/generic sources (array, hash, file, environment).
+is L<Complete::Util> which contains several generic routines, the main one is
+C<complete_array_elem()> which is used by most other completion routines.
 
 =head3 Environment-specific modules
 
@@ -86,7 +86,11 @@ to specify or customize the source of completion, for example for the function
 C<Complete::Util::complete_array_elem> there is an C<array> argument to specify
 the source array.
 
-=item * Follow behaviors specified in Complete::Common
+=item * Observe settings specified in L<Complete::Common>
+
+Example settings in Complete::Common include whether search should be
+case-insensitive, whether fuzzy searching should be done, etc. See the module's
+documentation for more details.
 
 =item * Return completion answer structure
 
@@ -164,7 +168,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Complete>.
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Complete>.
+Source repository is at L<https://github.com/perlancar/perl-Complete>.
 
 =head1 BUGS
 
